==> haskell-haddock-api-2.17.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-api
version: 2.17.3.1
id: haddock-api-2.17.3.1-KN3TSvO2Z0dI9weuCzNTPa
key: haddock-api-2.17.3.1-KN3TSvO2Z0dI9weuCzNTPa
license: BSD3
copyright: (c) Simon Marlow, David Waern
maintainer: Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
stability: experimental
homepage: http://www.haskell.org/haddock/
synopsis: A documentation-generation tool for Haskell libraries
description:
    Haddock is a documentation-generation tool for Haskell
    libraries
category: Documentation
author: Simon Marlow, David Waern
exposed: True
exposed-modules:
    Documentation.Haddock
hidden-modules: Haddock Haddock.Interface Haddock.Interface.Rename
                Haddock.Interface.Create Haddock.Interface.AttachInstances
                Haddock.Interface.LexParseRn Haddock.Interface.ParseModuleHeader
                Haddock.Interface.Specialize Haddock.Parser Haddock.Utils
                Haddock.Backends.Xhtml Haddock.Backends.Xhtml.Decl
                Haddock.Backends.Xhtml.DocMarkup Haddock.Backends.Xhtml.Layout
                Haddock.Backends.Xhtml.Names Haddock.Backends.Xhtml.Themes
                Haddock.Backends.Xhtml.Types Haddock.Backends.Xhtml.Utils
                Haddock.Backends.LaTeX Haddock.Backends.HaddockDB
                Haddock.Backends.Hoogle Haddock.Backends.Hyperlinker
                Haddock.Backends.Hyperlinker.Ast
                Haddock.Backends.Hyperlinker.Parser
                Haddock.Backends.Hyperlinker.Renderer
                Haddock.Backends.Hyperlinker.Types
                Haddock.Backends.Hyperlinker.Utils Haddock.ModuleTree Haddock.Types
                Haddock.Doc Haddock.Version Haddock.InterfaceFile Haddock.Options
                Haddock.GhcUtils Haddock.Syb Haddock.Convert Paths_haddock_api
abi: beb8a122de64cd996e1c34afa7a3a8f9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-api-2.17.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-api-2.17.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/haddock-api-2.17.3.1
hs-libraries: HShaddock-api-2.17.3.1-KN3TSvO2Z0dI9weuCzNTPa
depends:
    Cabal-1.24.0.0 array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 ghc-8.0.1 ghc-boot-8.0.1
    ghc-paths-0.1.0.9-GIOnKzk0HmEBZ77Q1HsThK
    haddock-library-1.4.3-7rEGzge05s5BxGssFs5tiB transformers-0.5.2.0
    xhtml-3000.2.1
haddock-interfaces: /usr/share/doc/haskell-haddock-api/html/haddock-api.haddock
haddock-html: /usr/share/doc/haskell-haddock-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-api-2.17.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-api
version: 2.17.4
id: haddock-api-2.17.4-2oc6jdou1s23DzKuE5Kc7x
key: haddock-api-2.17.4-2oc6jdou1s23DzKuE5Kc7x
license: BSD3
copyright: (c) Simon Marlow, David Waern
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
stability: experimental
homepage: http://www.haskell.org/haddock/
synopsis: A documentation-generation tool for Haskell libraries
description:
    Haddock is a documentation-generation tool for Haskell
    libraries
category: Documentation
author: Simon Marlow, David Waern
exposed: True
exposed-modules:
    Documentation.Haddock
hidden-modules: Haddock Haddock.Interface Haddock.Interface.Rename
                Haddock.Interface.Create Haddock.Interface.AttachInstances
                Haddock.Interface.LexParseRn Haddock.Interface.ParseModuleHeader
                Haddock.Interface.Specialize Haddock.Parser Haddock.Utils
                Haddock.Backends.Xhtml Haddock.Backends.Xhtml.Decl
                Haddock.Backends.Xhtml.DocMarkup Haddock.Backends.Xhtml.Layout
                Haddock.Backends.Xhtml.Names Haddock.Backends.Xhtml.Themes
                Haddock.Backends.Xhtml.Types Haddock.Backends.Xhtml.Utils
                Haddock.Backends.LaTeX Haddock.Backends.HaddockDB
                Haddock.Backends.Hoogle Haddock.Backends.Hyperlinker
                Haddock.Backends.Hyperlinker.Ast
                Haddock.Backends.Hyperlinker.Parser
                Haddock.Backends.Hyperlinker.Renderer
                Haddock.Backends.Hyperlinker.Types
                Haddock.Backends.Hyperlinker.Utils Haddock.ModuleTree Haddock.Types
                Haddock.Doc Haddock.Version Haddock.InterfaceFile Haddock.Options
                Haddock.GhcUtils Haddock.Syb Haddock.Convert Paths_haddock_api
abi: f1dd0e2a9b61735af26e37b0295478ef
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/haddock-api-2.17.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/haddock-api-2.17.4
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/haddock-api-2.17.4
hs-libraries: HShaddock-api-2.17.4-2oc6jdou1s23DzKuE5Kc7x
depends:
    Cabal-1.24.2.0 array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.3.0.0
    filepath-1.4.1.1 ghc-8.0.2 ghc-boot-8.0.2
    ghc-paths-0.1.0.9-AhaDlGOsRAepox069XzG
    haddock-library-1.4.3-JbTvLSEdh1LEWm8KMmBVQ transformers-0.5.2.0
    xhtml-3000.2.1
haddock-interfaces: /usr/share/doc/haskell-haddock-api/html/haddock-api.haddock
haddock-html: /usr/share/doc/haskell-haddock-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
